@@ -9,7 +9,6 @@
 
 #include "tangle-template.h"
 #include "tangle-actor.h"
-#include "tangle-action.h"
 #include "tangle-properties.h"
 #include "tangle-transition.h"
 #include "tangle-vault.h"
@@ -68,17 +67,6 @@ struct _TangleActorPrivate {
 	gdouble interactive_size_multiplier;
 	
 	ClutterActorBox layout_allocation;
-
-	TangleAction* button_press_action;
-	TangleAction* button_release_action;
-	TangleAction* enter_action;
-	TangleAction* leave_action;
-	TangleAction* motion_action;
-	TangleAction* scroll_action;
-	TangleAction* hide_action;
-	TangleAction* show_action;
-	TangleAction* show_completed_action;
-	TangleAction* transition_completed_action;
 	
 	ClutterTimeline* hiding_timeline;
 	
@@ -137,16 +125,6 @@ enum {
 	PROP_INTERACTIVE_SIZE_MULTIPLIER,
 	PROP_INTERACTIVE_SIZE_MULTIPLIER_SET,
 	PROP_STYLE,
-	PROP_BUTTON_PRESS_ACTION,
-	PROP_BUTTON_RELEASE_ACTION,
-	PROP_ENTER_ACTION,
-	PROP_LEAVE_ACTION,
-	PROP_MOTION_ACTION,
-	PROP_SCROLL_ACTION,
-	PROP_HIDE_ACTION,
-	PROP_SHOW_ACTION,
-	PROP_SHOW_COMPLETED_ACTION,
-	PROP_TRANSITION_COMPLETED_ACTION,
 	PROP_ACTION
 };
 
@@ -177,6 +155,8 @@ static ClutterScriptableIface* parent_scriptable_iface = NULL;
 ClutterAnimation* tangle_actor_animate(TangleActor* actor, gulong mode, guint duration, ...) {
 	ClutterAnimation* animation;
 	va_list args;
+
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), NULL);
 	
 	va_start(args, duration);
 	animation = tangle_object_animate_valist(G_OBJECT(actor), mode, duration, args);
@@ -189,6 +169,8 @@ ClutterAnimation* tangle_actor_animate_with_timeline(TangleActor* actor, gulong
 	ClutterAnimation* animation;
 	va_list args;
 	
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), NULL);
+
 	va_start(args, timeline);
 	animation = tangle_object_animate_valist_with_timeline(G_OBJECT(actor), mode, timeline, args);
 	va_end(args);
@@ -197,21 +179,26 @@ ClutterAnimation* tangle_actor_animate_with_timeline(TangleActor* actor, gulong
 }
 
 ClutterAnimation* tangle_actor_animatev(TangleActor* actor, gulong mode, guint duration, gint n_properties, const gchar* const property_names[], const GValue* property_values) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), NULL);
 
 	return tangle_object_animatev(G_OBJECT(actor), mode, duration, n_properties, property_names, property_values);
 }
 
 gboolean tangle_actor_stop_animation(TangleActor* actor, ClutterAnimation* animation) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 	
 	return tangle_object_stop_animation(G_OBJECT(actor), animation);
 }
 
 TangleTransition* tangle_actor_get_transition(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), NULL);
 
 	return actor->priv->transition;
 }
 
 void tangle_actor_set_transition(TangleActor* actor, TangleTransition* transition) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->transition != transition) {
 		if (transition) {
 			g_object_ref(transition);
@@ -225,11 +212,14 @@ void tangle_actor_set_transition(TangleActor* actor, TangleTransition* transitio
 }
 
 gboolean tangle_actor_should_transition_scale_children(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->transition_scale_children;
 }
 
 void tangle_actor_apply_transition_scale(TangleActor* actor) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->transition_scale_x != 1.0 || actor->priv->transition_scale_y != 1.0) {
 		cogl_translate(actor->priv->transition_scale_center_x, actor->priv->transition_scale_center_y, 0.0);
 		cogl_scale(actor->priv->transition_scale_x, actor->priv->transition_scale_y, 1.0);
@@ -238,6 +228,8 @@ void tangle_actor_apply_transition_scale(TangleActor* actor) {
 }
 
 void tangle_actor_get_transition_move(TangleActor* actor, gfloat* x_return, gfloat* y_return) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (x_return) {
 		*x_return = actor->priv->transition_move_x;
 	}
@@ -247,6 +239,8 @@ void tangle_actor_get_transition_move(TangleActor* actor, gfloat* x_return, gflo
 }
 
 void tangle_actor_set_transition_move(TangleActor* actor, gfloat x, gfloat y) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	g_object_freeze_notify(G_OBJECT(actor));
 	
 	if (actor->priv->transition_move_x != x) {
@@ -264,6 +258,8 @@ void tangle_actor_set_transition_move(TangleActor* actor, gfloat x, gfloat y) {
 }
 
 void tangle_actor_get_transition_scale(TangleActor* actor, gdouble* x_return, gdouble* y_return) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (x_return) {
 		*x_return = actor->priv->transition_scale_x;
 	}
@@ -273,6 +269,8 @@ void tangle_actor_get_transition_scale(TangleActor* actor, gdouble* x_return, gd
 }
 
 void tangle_actor_set_transition_scale(TangleActor* actor, gdouble x, gdouble y) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	g_object_freeze_notify(G_OBJECT(actor));
 	
 	if (actor->priv->transition_scale_x != x) {
@@ -293,6 +291,8 @@ void tangle_actor_show(TangleActor* actor) {
 	ClutterActorBox* current_allocation;
 	ClutterTimeline* timeline = NULL;
 
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (TANGLE_ACTOR_IS_HIDING(actor) && !actor->priv->destroy) {
 		TANGLE_ACTOR_UNSET_FLAGS(actor, TANGLE_ACTOR_HIDING);
 		TANGLE_ACTOR_SET_FLAGS(actor, TANGLE_ACTOR_SHOWING);
@@ -349,6 +349,8 @@ void tangle_actor_hide_all_animated(TangleActor* actor) {
 	ClutterActorBox* current_allocation;
 	ClutterTimeline* timeline = NULL;
 	
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	actor->priv->hide_all = TRUE;
 	
 	if (CLUTTER_ACTOR_IS_VISIBLE(CLUTTER_ACTOR(actor)) && !TANGLE_ACTOR_IS_HIDING(actor)) {
@@ -377,6 +379,8 @@ void tangle_actor_hide_all_animated(TangleActor* actor) {
 void tangle_actor_destroy_animated(TangleActor* actor) {
 	ClutterActorBox* current_allocation;
 	ClutterTimeline* timeline = NULL;
+
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
 	
 	actor->priv->destroy = TRUE;
 	
@@ -412,6 +416,7 @@ void tangle_actor_destroy_animated(TangleActor* actor) {
  * Return value: the depth position of the actor
  */
 gint tangle_actor_get_depth_position(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), 0);
 
 	return actor->priv->depth_position;
 }
@@ -427,6 +432,8 @@ gint tangle_actor_get_depth_position(TangleActor* actor) {
  */
 void tangle_actor_set_depth_position(TangleActor* actor, gint depth_position) {
 	ClutterActor* parent;
+
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
 	
 	if (actor->priv->depth_position != depth_position) {
 		actor->priv->depth_position = depth_position;
@@ -440,10 +447,14 @@ void tangle_actor_set_depth_position(TangleActor* actor, gint depth_position) {
 }
 
 void tangle_actor_get_margin(TangleActor* actor, TangleSpacing* spacing) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	*spacing = actor->priv->margin;
 }
 	
 void tangle_actor_set_margin(TangleActor* actor, const TangleSpacing* spacing) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (!actor->priv->margin_set || !tangle_spacing_equal(&actor->priv->margin, spacing)) {
 		g_object_freeze_notify(G_OBJECT(actor));
 		
@@ -467,11 +478,14 @@ void tangle_actor_set_margin(TangleActor* actor, const TangleSpacing* spacing) {
 }
 
 gboolean tangle_actor_get_margin_set(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->margin_set;
 }
 
 void tangle_actor_set_margin_set(TangleActor* actor, gboolean is_set) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->margin_set != is_set) {
 		g_object_freeze_notify(G_OBJECT(actor));
 
@@ -485,6 +499,8 @@ void tangle_actor_set_margin_set(TangleActor* actor, gboolean is_set) {
 }
 
 void tangle_actor_get_max_size(TangleActor* actor, gfloat* max_width_p, gfloat* max_height_p) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->max_width_set) {
 		*max_width_p = actor->priv->max_width_set;
 	} else {
@@ -498,6 +514,8 @@ void tangle_actor_get_max_size(TangleActor* actor, gfloat* max_width_p, gfloat*
 }
 
 void tangle_actor_set_max_size(TangleActor* actor, gfloat max_width, gfloat max_height) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	g_object_freeze_notify(G_OBJECT(actor));
 	
 	set_max_width(actor, max_width);
@@ -507,11 +525,14 @@ void tangle_actor_set_max_size(TangleActor* actor, gfloat max_width, gfloat max_
 }
 
 gdouble tangle_actor_get_aspect_ratio(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), 0.0);
 
 	return actor->priv->aspect_ratio;
 }
 
 void tangle_actor_set_aspect_ratio(TangleActor* actor, gdouble aspect_ratio) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->aspect_ratio != aspect_ratio) {
 		actor->priv->aspect_ratio = aspect_ratio;
 		tangle_actor_set_aspect_ratio_set(actor, TRUE);
@@ -521,11 +542,14 @@ void tangle_actor_set_aspect_ratio(TangleActor* actor, gdouble aspect_ratio) {
 }
 
 gboolean tangle_actor_get_aspect_ratio_set(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->aspect_ratio_set;
 }
 
 void tangle_actor_set_aspect_ratio_set(TangleActor* actor, gboolean is_set) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->aspect_ratio_set != is_set) {
 		actor->priv->aspect_ratio_set = is_set;
 		g_object_notify(G_OBJECT(actor), "aspect-ratio-set");
@@ -534,11 +558,14 @@ void tangle_actor_set_aspect_ratio_set(TangleActor* actor, gboolean is_set) {
 }
 
 gdouble tangle_actor_get_alignment_x(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), 0.0);
 
 	return actor->priv->alignment_x;
 }
 
 void tangle_actor_set_alignment_x(TangleActor* actor, gdouble alignment_x) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->alignment_x != alignment_x) {
 		actor->priv->alignment_x = alignment_x;
 		g_object_notify(G_OBJECT(actor), "alignment-x");
@@ -547,11 +574,14 @@ void tangle_actor_set_alignment_x(TangleActor* actor, gdouble alignment_x) {
 }
 
 gdouble tangle_actor_get_alignment_y(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), 0.0);
 
 	return actor->priv->alignment_y;
 }
 
 void tangle_actor_set_alignment_y(TangleActor* actor, gdouble alignment_y) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->alignment_y != alignment_y) {
 		actor->priv->alignment_y = alignment_y;
 		g_object_notify(G_OBJECT(actor), "alignment-y");
@@ -560,16 +590,21 @@ void tangle_actor_set_alignment_y(TangleActor* actor, gdouble alignment_y) {
 }
 
 void tangle_actor_get_aligned_allocation(TangleActor* actor, ClutterActorBox* aligned_allocation) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	*aligned_allocation = actor->priv->aligned_allocation;
 }
 
 
 gboolean tangle_actor_get_interacting(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->interacting;
 }
 
 void tangle_actor_set_interacting(TangleActor* actor, gboolean interacting) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->interacting != interacting) {
 		actor->priv->interacting = interacting;
 		g_object_notify(G_OBJECT(actor), "interacting");
@@ -578,11 +613,14 @@ void tangle_actor_set_interacting(TangleActor* actor, gboolean interacting) {
 }
 
 gboolean tangle_actor_get_dragging(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->dragging;
 }
 
 void tangle_actor_set_dragging(TangleActor* actor, gboolean dragging) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->dragging != dragging) {
 		actor->priv->dragging = dragging;
 		g_object_notify(G_OBJECT(actor), "dragging");
@@ -590,11 +628,13 @@ void tangle_actor_set_dragging(TangleActor* actor, gboolean dragging) {
 }
 
 gboolean tangle_actor_get_ancestor_interacting(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->ancestor_interacting;
 }
 
 gboolean tangle_actor_get_ancestor_dragging(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->ancestor_dragging;
 }
@@ -606,6 +646,8 @@ void tangle_actor_get_preferred_width(TangleActor* actor, gfloat for_height, gbo
 	gboolean natural_width_set;
 	TangleActorClass* actor_class;
 
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (for_height >= 0 && actor->priv->aspect_ratio_set) {
 		if (min_width_p) {
 			*min_width_p = actor->priv->aspect_ratio * for_height;
@@ -680,6 +722,8 @@ void tangle_actor_get_preferred_height(TangleActor* actor, gfloat for_width, gbo
 	gboolean natural_height_set;
 	TangleActorClass* actor_class;
 
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (for_width >= 0 && actor->priv->aspect_ratio_set) {
 		if (min_height_p) {
 			*min_height_p = for_width / actor->priv->aspect_ratio;
@@ -750,6 +794,8 @@ void tangle_actor_get_preferred_height(TangleActor* actor, gfloat for_width, gbo
 void tangle_actor_get_preferred_size(TangleActor* actor, gboolean interacting, gfloat* min_width_p, gfloat* min_height_p, gfloat* natural_width_p, gfloat* natural_height_p, gfloat* max_width_p, gfloat* max_height_p) {
 	ClutterRequestMode request_mode;
 	gfloat natural_size;
+
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
 	
 	g_object_get(actor, "request-mode", &request_mode, NULL);
 	if (request_mode == CLUTTER_REQUEST_HEIGHT_FOR_WIDTH) {
@@ -769,11 +815,14 @@ void tangle_actor_get_preferred_size(TangleActor* actor, gboolean interacting, g
 }
 
 gdouble tangle_actor_get_interactive_size_multiplier(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), 0.0);
 
 	return actor->priv->interactive_size_multiplier;
 }
 
 void tangle_actor_set_interactive_size_multiplier(TangleActor* actor, gdouble multiplier) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->interactive_size_multiplier != multiplier) {
 		g_object_freeze_notify(G_OBJECT(actor));
 		
@@ -789,11 +838,14 @@ void tangle_actor_set_interactive_size_multiplier(TangleActor* actor, gdouble mu
 }
 
 gboolean tangle_actor_get_interactive_size_multiplier_set(TangleActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_ACTOR(actor), FALSE);
 
 	return actor->priv->interactive_size_multiplier_set;
 }
 
 void tangle_actor_set_interactive_size_multiplier_set(TangleActor* actor, gboolean is_set) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	if (actor->priv->interactive_size_multiplier_set != is_set) {
 		actor->priv->interactive_size_multiplier_set = is_set;
 		g_object_notify(G_OBJECT(actor), "interactive-size-multiplier-set");
@@ -804,10 +856,14 @@ void tangle_actor_set_interactive_size_multiplier_set(TangleActor* actor, gboole
 }
 
 void tangle_actor_get_layout_allocation(TangleActor* actor, ClutterActorBox* actor_box) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	*actor_box = actor->priv->layout_allocation;
 }
 
 void tangle_actor_set_layout_allocation(TangleActor* actor, const ClutterActorBox* actor_box) {
+	g_return_if_fail(TANGLE_IS_ACTOR(actor));
+
 	actor->priv->layout_allocation = *actor_box;
 }
 
@@ -878,6 +934,7 @@ ClutterAction* tangle_actor_get_action_by_type(ClutterActor* actor, GType type)
 	GList* list;
 	GList* list_item;
 	
+	g_return_val_if_fail(CLUTTER_IS_ACTOR(actor), NULL);
 	g_return_val_if_fail(g_type_is_a(type, CLUTTER_TYPE_ACTION), NULL);
 	
 	list = clutter_actor_get_actions(actor);
@@ -1073,12 +1130,6 @@ static void tangle_actor_real_show(ClutterActor* clutter_actor) {
 	actor = TANGLE_ACTOR(clutter_actor);
 
 	CLUTTER_ACTOR_CLASS(tangle_actor_parent_class)->show(clutter_actor);
-
-	if (actor->priv->show_action) {
-		properties = tangle_properties_new();
-		tangle_action_execute_full(actor->priv->show_action, G_OBJECT(actor), "show", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
 }
 
 static void tangle_actor_hide(ClutterActor* clutter_actor) {
@@ -1101,105 +1152,9 @@ static void tangle_actor_hide(ClutterActor* clutter_actor) {
 		actor->priv->hiding_timeline = NULL;
 	}
 
-	if (actor->priv->hide_action) {
-		properties = tangle_properties_new();
-		tangle_action_execute_full(actor->priv->hide_action, G_OBJECT(actor), "hide", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
 	CLUTTER_ACTOR_CLASS(tangle_actor_parent_class)->hide(clutter_actor);
 }
 
-static gboolean tangle_actor_button_press_event(ClutterActor* clutter_actor, ClutterButtonEvent* event) {
-	TangleActor* actor;
-	TangleProperties* properties;
-	
-	actor = TANGLE_ACTOR(clutter_actor);
-	if (actor->priv->button_press_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "button", G_TYPE_UINT /* TODO: G_TYPE_UINT32 */, event->button, NULL);
-		tangle_action_execute_full(actor->priv->button_press_action, G_OBJECT(actor), "button-press", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
-	return FALSE;
-}
-
-static gboolean tangle_actor_button_release_event(ClutterActor* clutter_actor, ClutterButtonEvent* event) {
-	TangleActor* actor;
-	TangleProperties* properties;
-	
-	actor = TANGLE_ACTOR(clutter_actor);
-	if (actor->priv->button_release_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "button", G_TYPE_UINT /* TODO: G_TYPE_UINT32 */, event->button, NULL);
-		tangle_action_execute_full(actor->priv->button_release_action, G_OBJECT(actor), "button-release", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
-	return FALSE;
-}
-
-static gboolean tangle_actor_enter_event(ClutterActor* clutter_actor, ClutterCrossingEvent* event) {
-	TangleActor* actor;
-	TangleProperties* properties;
-	
-	actor = TANGLE_ACTOR(clutter_actor);
-	if (actor->priv->enter_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "related", CLUTTER_TYPE_ACTOR, event->related, NULL);
-		tangle_action_execute_full(actor->priv->enter_action, G_OBJECT(actor), "enter", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
-	return FALSE;
-}
-
-static gboolean tangle_actor_leave_event(ClutterActor* clutter_actor, ClutterCrossingEvent* event) {
-	TangleActor* actor;
-	TangleProperties* properties;
-	
-	actor = TANGLE_ACTOR(clutter_actor);
-	if (actor->priv->leave_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "related", CLUTTER_TYPE_ACTOR, event->related, NULL);
-		tangle_action_execute_full(actor->priv->leave_action, G_OBJECT(actor), "leave", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
-	return FALSE;
-}
-
-static gboolean tangle_actor_motion_event(ClutterActor* clutter_actor, ClutterMotionEvent* event) {
-	TangleActor* actor;
-	TangleProperties* properties;
-	
-	actor = TANGLE_ACTOR(clutter_actor);
-	if (actor->priv->motion_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "x", G_TYPE_FLOAT, event->x, "y", G_TYPE_FLOAT, event->y, NULL);
-		tangle_action_execute_full(actor->priv->motion_action, G_OBJECT(actor), "motion", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
-	return FALSE;
-}
-
-static gboolean tangle_actor_scroll_event(ClutterActor* clutter_actor, ClutterScrollEvent* event) {
-	TangleActor* actor;
-	TangleProperties* properties;
-	
-	actor = TANGLE_ACTOR(clutter_actor);
-	if (actor->priv->scroll_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "direction", CLUTTER_TYPE_SCROLL_DIRECTION, event->direction, NULL);
-		tangle_action_execute_full(actor->priv->scroll_action, G_OBJECT(actor), "scroll", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
-	return FALSE;
-}
-
 static void tangle_actor_parent_set(ClutterActor* actor, ClutterActor* old_parent) {
 	ClutterActor* parent;
 	
@@ -1231,27 +1186,9 @@ static ClutterTimeline* tangle_actor_animate_transition(TangleActor* actor, Clut
 }
 
 static void tangle_actor_transition_completed(TangleActor* actor, ClutterActorBox* old_box, ClutterActorBox* current_box) {
-	TangleProperties* properties;
-	
-	if (actor->priv->transition_completed_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "old-allocation", CLUTTER_TYPE_ACTOR_BOX, old_box, "current-allocation", CLUTTER_TYPE_ACTOR_BOX, current_box, NULL);
-		tangle_action_execute_full(actor->priv->transition_completed_action, G_OBJECT(actor), "transition-completed", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
 }
 
 static void tangle_actor_show_completed(TangleActor* actor, ClutterActorBox* current_box) {
-	TangleProperties* properties;
-	
-	if (actor->priv->show_completed_action) {
-		properties = tangle_properties_new();
-		tangle_properties_set(properties, "current-allocation", CLUTTER_TYPE_ACTOR_BOX, current_box, NULL);
-		tangle_action_execute_full(actor->priv->show_completed_action, G_OBJECT(actor), "show-completed", properties);
-		g_object_unref(G_OBJECT(properties));
-	}
-	
 }
 
 static void tangle_actor_paint_event_handler(ClutterActor* self, gpointer user_data) {
@@ -1278,13 +1215,6 @@ static void tangle_actor_pick_event_handler(ClutterActor* self, gpointer user_da
 	}
 }
 
-#define SET_ACTION(a) \
-	if (actor->priv->a) { \
-		g_object_unref(actor->priv->a); \
-	} \
-	actor->priv->a = TANGLE_ACTION(g_value_get_object(value)); \
-	g_object_ref(actor->priv->a);
-
 static void tangle_actor_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	TangleActor* actor;
 	
@@ -1381,36 +1311,6 @@ static void tangle_actor_set_property(GObject* object, guint prop_id, const GVal
 		case PROP_INTERACTIVE_SIZE_MULTIPLIER_SET:
 			tangle_actor_set_interactive_size_multiplier_set(actor, g_value_get_boolean(value));
 			break;
-		case PROP_BUTTON_PRESS_ACTION:
-			SET_ACTION(button_press_action);
-			break;
-		case PROP_BUTTON_RELEASE_ACTION:
-			SET_ACTION(button_press_action);
-			break;
-		case PROP_ENTER_ACTION:
-			SET_ACTION(enter_action);
-			break;
-		case PROP_LEAVE_ACTION:
-			SET_ACTION(leave_action);
-			break;
-		case PROP_MOTION_ACTION:
-			SET_ACTION(motion_action);
-			break;
-		case PROP_SCROLL_ACTION:
-			SET_ACTION(scroll_action);
-			break;
-		case PROP_HIDE_ACTION:
-			SET_ACTION(hide_action);
-			break;
-		case PROP_SHOW_ACTION:
-			SET_ACTION(show_action);
-			break;
-		case PROP_SHOW_COMPLETED_ACTION:
-			SET_ACTION(show_completed_action);
-			break;
-		case PROP_TRANSITION_COMPLETED_ACTION:
-			SET_ACTION(transition_completed_action);
-			break;
 		case PROP_ACTION:
 			clutter_actor_add_action(CLUTTER_ACTOR(actor), CLUTTER_ACTION(g_value_get_object(value)));
 			break;
@@ -1503,36 +1403,6 @@ static void tangle_actor_get_property(GObject* object, guint prop_id, GValue* va
 		case PROP_INTERACTIVE_SIZE_MULTIPLIER_SET:
 			g_value_set_boolean(value, actor->priv->interactive_size_multiplier_set);
 			break;
-		case PROP_BUTTON_PRESS_ACTION:
-			g_value_set_object(value, actor->priv->button_press_action);
-			break;
-		case PROP_BUTTON_RELEASE_ACTION:
-			g_value_set_object(value, actor->priv->button_release_action);
-			break;
-		case PROP_ENTER_ACTION:
-			g_value_set_object(value, actor->priv->enter_action);
-			break;
-		case PROP_LEAVE_ACTION:
-			g_value_set_object(value, actor->priv->leave_action);
-			break;
-		case PROP_MOTION_ACTION:
-			g_value_set_object(value, actor->priv->motion_action);
-			break;
-		case PROP_SCROLL_ACTION:
-			g_value_set_object(value, actor->priv->scroll_action);
-			break;
-		case PROP_HIDE_ACTION:
-			g_value_set_object(value, actor->priv->hide_action);
-			break;
-		case PROP_SHOW_ACTION:
-			g_value_set_object(value, actor->priv->show_action);
-			break;
-		case PROP_SHOW_COMPLETED_ACTION:
-			g_value_set_object(value, actor->priv->show_completed_action);
-			break;
-		case PROP_TRANSITION_COMPLETED_ACTION:
-			g_value_set_object(value, actor->priv->transition_completed_action);
-			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -1545,18 +1415,6 @@ static void tangle_actor_dispose(GObject* object) {
 	
 	actor = TANGLE_ACTOR(object);
 
-
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->button_press_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->button_release_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->enter_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->leave_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->motion_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->scroll_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->hide_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->show_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->show_completed_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->transition_completed_action);
-
 	if (actor->priv->hiding_timeline) {
 		complete_timeline(actor->priv->hiding_timeline);
 		g_object_unref(actor->priv->hiding_timeline);
@@ -1593,12 +1451,6 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	clutter_actor_class->pick = tangle_actor_pick;
 	clutter_actor_class->show = tangle_actor_real_show;
 	clutter_actor_class->hide = tangle_actor_hide;
-	clutter_actor_class->button_press_event = tangle_actor_button_press_event;
-	clutter_actor_class->button_release_event = tangle_actor_button_press_event;
-	clutter_actor_class->enter_event = tangle_actor_enter_event;
-	clutter_actor_class->leave_event = tangle_actor_leave_event;
-	clutter_actor_class->motion_event = tangle_actor_motion_event;
-	clutter_actor_class->scroll_event = tangle_actor_scroll_event;
 	clutter_actor_class->parent_set = tangle_actor_parent_set;
 	
 	actor_class->animate_transition = tangle_actor_animate_transition;
@@ -1879,96 +1731,6 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	                                "Whether the interactive size multiplier is set or not",
 	                                FALSE,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:button-press-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_BUTTON_PRESS_ACTION,
-	                                g_param_spec_object("button-press-action",
-	                                "Button press action",
-	                                "The action that correspond to the button press event",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:button-release-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_BUTTON_RELEASE_ACTION,
-	                                g_param_spec_object("button-release-action",
-	                                "Button release action",
-	                                "The action that correspond to the button release event",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:enter-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_ENTER_ACTION,
-	                                g_param_spec_object("enter-action",
-	                                "Enter action",
-	                                "The action that correspond to the enter event",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:leave-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_LEAVE_ACTION,
-	                                g_param_spec_object("leave-action",
-	                                "Button pressa ction",
-	                                "The action that correspond to the leave event",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:motion-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_MOTION_ACTION,
-	                                g_param_spec_object("motion-action",
-	                                "Button pressa ction",
-	                                "The action that correspond to the motion event",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:scroll-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_SCROLL_ACTION,
-	                                g_param_spec_object("scroll-action",
-	                                "Button pressa ction",
-	                                "The action that correspond to the scroll event",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:hide-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_HIDE_ACTION,
-	                                g_param_spec_object("hide-action",
-	                                "Hide action",
-	                                "The action that correspond to the hide signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:show-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_SHOW_ACTION,
-	                                g_param_spec_object("show-action",
-	                                "Show action",
-	                                "The action that correspond to the show signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:show-completed-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_SHOW_COMPLETED_ACTION,
-	                                g_param_spec_object("show-completed-action",
-	                                "Show completed action",
-	                                "The action that correspond to the show-completed signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
-	/**
-	 * TangleActor:transition-completed-action:
-	 */
-	g_object_class_install_property(gobject_class, PROP_TRANSITION_COMPLETED_ACTION,
-	                                g_param_spec_object("transition-completed-action",
-	                                "Transition completed action",
-	                                "The action that correspond to the transition completed signal",
-	                                TANGLE_TYPE_ACTION,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleActor:action:
 	 *
