@@ -94,32 +94,39 @@ TangleBinding* tangle_binding_new(GObject* object_a, const gchar* property_a, GO
 }
 
 GObject* tangle_binding_get_object_a(TangleBinding* binding) {
+	g_return_val_if_fail(TANGLE_IS_BINDING(binding), NULL);
 
 	return binding->priv->objects[0];
 }
 
 const gchar* tangle_binding_get_property_a(TangleBinding* binding) {
+	g_return_val_if_fail(TANGLE_IS_BINDING(binding), NULL);
 
 	return binding->priv->properties[0];
 }
 
 GObject* tangle_binding_get_object_b(TangleBinding* binding) {
+	g_return_val_if_fail(TANGLE_IS_BINDING(binding), NULL);
 
 	return binding->priv->objects[1];
 }
 
 const gchar* tangle_binding_get_property_b(TangleBinding* binding) {
+	g_return_val_if_fail(TANGLE_IS_BINDING(binding), NULL);
 
 	return binding->priv->properties[1];
 }
 
 TangleBindingDirection tangle_binding_get_direction(TangleBinding* binding) {
+	g_return_val_if_fail(TANGLE_IS_BINDING(binding), TANGLE_BINDING_NONE);
 
 	return binding->priv->direction;
 }
 
 gboolean tangle_binding_get_multiplier(TangleBinding* binding, GValue* value_return) {
 	gboolean retvalue = FALSE;
+
+	g_return_val_if_fail(TANGLE_IS_BINDING(binding), FALSE);
 	
 	if (G_VALUE_TYPE(&binding->priv->multiplier)) {
 		g_value_init(value_return, G_VALUE_TYPE(&binding->priv->multiplier));
@@ -131,6 +138,7 @@ gboolean tangle_binding_get_multiplier(TangleBinding* binding, GValue* value_ret
 }
 
 void tangle_binding_set_multiplier(TangleBinding* binding, const GValue* value) {
+	g_return_if_fail(TANGLE_IS_BINDING(binding));
 	g_return_if_fail(G_VALUE_TYPE(value) == G_VALUE_TYPE(&binding->priv->current_value[0]));
 	g_return_if_fail(tangle_value_is_calculation_supported(G_VALUE_TYPE(value)));
 	
@@ -149,6 +157,8 @@ void tangle_binding_set_multiplier(TangleBinding* binding, const GValue* value)
 	
 gboolean tangle_binding_get_constant_term(TangleBinding* binding, GValue* value_return) {
 	gboolean retvalue = FALSE;
+
+	g_return_val_if_fail(TANGLE_IS_BINDING(binding), FALSE);
 	
 	if (G_VALUE_TYPE(&binding->priv->constant_term)) {
 		g_value_init(value_return, G_VALUE_TYPE(&binding->priv->constant_term));
@@ -160,6 +170,7 @@ gboolean tangle_binding_get_constant_term(TangleBinding* binding, GValue* value_
 }
 
 void tangle_binding_set_constant_term(TangleBinding* binding, const GValue* value) {
+	g_return_if_fail(TANGLE_IS_BINDING(binding));
 	g_return_if_fail(G_VALUE_TYPE(value) == G_VALUE_TYPE(&binding->priv->current_value[0]));
 	g_return_if_fail(tangle_value_is_calculation_supported(G_VALUE_TYPE(value)));
 	
@@ -179,7 +190,9 @@ void tangle_binding_set_constant_term(TangleBinding* binding, const GValue* valu
 GList* tangle_object_get_bindings_readonly(GObject* object, const gchar* property) {
 	GList* list = NULL;
 	GHashTable* hash_table;
-	
+
+	g_return_val_if_fail(G_IS_OBJECT(object), NULL);	
+
 	if ((hash_table = (GHashTable*)g_object_get_qdata(object, quark_property_bindings))) {
 		list = g_hash_table_lookup(hash_table, property);
 	}
