@@ -9,6 +9,7 @@
 
 #include "tangle-button.h"
 #include "tangle-misc.h"
+#include "tangle-highlight-effect.h"
 #include "marshalers.h"
 
 /**
@@ -26,7 +27,10 @@ enum {
 	PROP_INTERACTIVE_BACKGROUND_ACTOR,
 	PROP_SELECTED_BACKGROUND_ACTOR,
 	PROP_SELECTED,
-	PROP_CLICKED_ACTION
+	PROP_HIGHLIGHT_COLOR,
+	PROP_HIGHLIGHT_DISTANCE,
+	PROP_HIGHLIGHT_ACTIVATE_DURATION,
+	PROP_HIGHLIGHT_INACTIVATE_DURATION
 };
 
 enum {
@@ -39,9 +43,13 @@ struct _TangleButtonPrivate {
 	ClutterActor* normal_background_actor;
 	ClutterActor* interactive_background_actor;
 	ClutterActor* selected_background_actor;
-	TangleAction* clicked_action;
+	gfloat highlight_distance;
+	guint highlight_activate_duration;
+	guint highlight_inactivate_duration;
 
 	ClutterActor* button_release_event_handler_actor;
+	ClutterEffect* highlight_effect;
+	ClutterAnimation* highlight_animation;
 
 	guint active : 1;
 	guint inside : 1;
@@ -60,6 +68,7 @@ static void begin_interacting(TangleButton* button);
 static void end_interacting(TangleButton* button);
 
 static guint signals[LAST_SIGNAL];
+static const ClutterColor white = { 255, 255, 255, 255 };
 
 GType tangle_button_mode_get_type(void) {
 	static GType type = 0;
@@ -117,11 +126,13 @@ ClutterActor* tangle_button_new_radio_with_background_actors(ClutterActor* norma
 }
 
 TangleButtonMode tangle_button_get_mode(TangleButton* button) {
+	g_return_if_fail(TANGLE_IS_BUTTON(button));
 
 	return button->priv->mode;
 }
 
 void tangle_button_set_mode(TangleButton* button, TangleButtonMode mode) {
+	g_return_if_fail(TANGLE_IS_BUTTON(button));
 	g_return_if_fail(mode >= TANGLE_BUTTON_CLICKABLE && mode <= TANGLE_BUTTON_RADIO);
 	
 	if (button->priv->mode != mode) {
@@ -225,6 +236,8 @@ void tangle_button_set_selected_background_actor(TangleButton* button, ClutterAc
 
 gboolean tangle_button_get_selected(TangleButton* button) {
 	gboolean selected = FALSE;
+
+	g_return_val_if_fail(TANGLE_IS_BUTTON(button), FALSE);
 	
 	if ((button->priv->mode == TANGLE_BUTTON_SELECTABLE || button->priv->mode == TANGLE_BUTTON_RADIO)) {
 		selected = button->priv->selected;
@@ -234,6 +247,7 @@ gboolean tangle_button_get_selected(TangleButton* button) {
 }
 	
 void tangle_button_set_selected(TangleButton* button, gboolean selected) {
+	g_return_if_fail(TANGLE_IS_BUTTON(button));
 	g_return_if_fail((button->priv->mode == TANGLE_BUTTON_SELECTABLE || button->priv->mode == TANGLE_BUTTON_RADIO));
 	
 	if (button->priv->selected != selected) {
@@ -250,14 +264,16 @@ void tangle_button_set_selected(TangleButton* button, gboolean selected) {
 	}
 }
 
-static gboolean tangle_button_clicked(TangleButton* button) {
-	TangleProperties* properties;
-	
-	if (button->priv->clicked_action) {
-		properties = tangle_properties_new();
-		tangle_action_execute_full(button->priv->clicked_action, G_OBJECT(button), "clicked", properties);
-		g_object_unref(G_OBJECT(properties));
+void tangle_button_stop_highlighting(TangleButton* button) {
+	g_return_if_fail(TANGLE_IS_BUTTON(button));
+
+	if (button->priv->highlight_animation) {
+		clutter_animation_completed(button->priv->highlight_animation);
 	}
+	tangle_highlight_effect_set_distance(TANGLE_HIGHLIGHT_EFFECT(button->priv->highlight_effect), 0.0);
+}
+
+static gboolean tangle_button_clicked(TangleButton* button) {
 	
 	return FALSE;
 }
@@ -319,12 +335,17 @@ static void tangle_button_set_property(GObject* object, guint prop_id, const GVa
 		case PROP_SELECTED:
 			tangle_button_set_selected(button, g_value_get_boolean(value));
 			break;
-		case PROP_CLICKED_ACTION:
-			if (button->priv->clicked_action) {
-				g_object_unref(button->priv->clicked_action);
-			}
-			button->priv->clicked_action = TANGLE_ACTION(g_value_get_object(value));
-			g_object_ref(button->priv->clicked_action);
+		case PROP_HIGHLIGHT_COLOR:;
+			tangle_highlight_effect_set_color(TANGLE_HIGHLIGHT_EFFECT(button->priv->highlight_effect), clutter_value_get_color(value));
+			break;
+		case PROP_HIGHLIGHT_DISTANCE:
+			button->priv->highlight_distance = g_value_get_float(value);
+			break;
+		case PROP_HIGHLIGHT_ACTIVATE_DURATION:
+			button->priv->highlight_activate_duration = g_value_get_uint(value);
+			break;
+		case PROP_HIGHLIGHT_INACTIVATE_DURATION:
+			button->priv->highlight_inactivate_duration = g_value_get_uint(value);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -334,6 +355,7 @@ static void tangle_button_set_property(GObject* object, guint prop_id, const GVa
 
 static void tangle_button_get_property(GObject* object, guint prop_id, GValue* value, GParamSpec* pspec) {
         TangleButton* button;
+	ClutterColor color;
 
 	button = TANGLE_BUTTON(object);
 
@@ -353,8 +375,18 @@ static void tangle_button_get_property(GObject* object, guint prop_id, GValue* v
 		case PROP_SELECTED:
 			g_value_set_boolean(value, button->priv->selected);
 			break;
-		case PROP_CLICKED_ACTION:
-			g_value_set_object(value, button->priv->clicked_action);
+		case PROP_HIGHLIGHT_COLOR:
+			tangle_highlight_effect_get_color(TANGLE_HIGHLIGHT_EFFECT(button->priv->highlight_effect), &color);
+			clutter_value_set_color(value, &color);
+			break;
+		case PROP_HIGHLIGHT_DISTANCE:
+			g_value_set_float(value, button->priv->highlight_distance);
+			break;
+		case PROP_HIGHLIGHT_ACTIVATE_DURATION:
+			g_value_set_uint(value, button->priv->highlight_activate_duration);
+			break;
+		case PROP_HIGHLIGHT_INACTIVATE_DURATION:
+			g_value_set_uint(value, button->priv->highlight_inactivate_duration);
 			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -362,6 +394,15 @@ static void tangle_button_get_property(GObject* object, guint prop_id, GValue* v
         }
 }
 
+static void tangle_button_constructed(GObject* object) {
+	TangleButton* button;
+	
+	button = TANGLE_BUTTON(object);
+
+	button->priv->highlight_effect = tangle_highlight_effect_new();
+	clutter_actor_add_effect(CLUTTER_ACTOR(button), button->priv->highlight_effect);
+}
+
 static void tangle_button_dispose(GObject* object) {
 	TangleButton* button;
 	
@@ -370,7 +411,6 @@ static void tangle_button_dispose(GObject* object) {
 	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->normal_background_actor);
 	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->interactive_background_actor);
 	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->selected_background_actor);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(button->priv->clicked_action);
 	
 	if (button->priv->button_release_event_handler_actor) {
 		g_signal_handlers_disconnect_by_func(button->priv->button_release_event_handler_actor, G_CALLBACK(on_button_release_event), button);
@@ -385,6 +425,7 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	ClutterActorClass* clutter_actor_class = CLUTTER_ACTOR_CLASS(button_class);
 	TangleActorClass* actor_class = TANGLE_ACTOR_CLASS(button_class);
 
+	gobject_class->constructed = tangle_button_constructed;
 	gobject_class->dispose = tangle_button_dispose;
 	gobject_class->set_property = tangle_button_set_property;
 	gobject_class->get_property = tangle_button_get_property;
@@ -442,13 +483,48 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	                                FALSE,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
-	 * TangleButton:on-clicked-action:
+	 * TangleButton:highligh-color:
+	 *
+	 * The color that is used to highlight the button when it is interactive.
 	 */
-	g_object_class_install_property(gobject_class, PROP_CLICKED_ACTION,
-	                                g_param_spec_object("clicked-action",
-	                                "Clicked action",
-	                                "Action that is executed on clicked signal",
-	                                TANGLE_TYPE_ACTION,
+	g_object_class_install_property(gobject_class, PROP_HIGHLIGHT_COLOR,
+	                                clutter_param_spec_color("highlight-color",
+	                                "Highlight color",
+	                                "The color that is used to highlight the button when it is interactive",
+	                                &white,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleButton:highligh-distance:
+	 *
+	 * The distance in pixels how far the highlighting is drawn.
+	 */
+	g_object_class_install_property(gobject_class, PROP_HIGHLIGHT_DISTANCE,
+	                                g_param_spec_float("highlight-distance",
+	                                "Highlight distance",
+	                                "The distance in pixels how far the highlighting is drawn",
+	                                0.0, G_MAXFLOAT, 7.0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleButton:highligh-activate-duration:
+	 *
+	 * The duration in milliseconds how long it takes to have highlighting in its full intensity after activating the button.
+	 */
+	g_object_class_install_property(gobject_class, PROP_HIGHLIGHT_ACTIVATE_DURATION,
+	                                g_param_spec_uint("highlight-activate-duration",
+	                                "Highligh activate duration",
+	                                "The duration in milliseconds how long it takes to have highlighting in its full intensity after activating the button",
+	                                0, G_MAXUINT, 250,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleButton:highligh-inactivate-duration:
+	 *
+	 * The duration in milliseconds how long it takes to fade off highlighting after inactivating the button.
+	 */
+	g_object_class_install_property(gobject_class, PROP_HIGHLIGHT_INACTIVATE_DURATION,
+	                                g_param_spec_uint("highlight-inactivate-duration",
+	                                "Highligh inactivate duration",
+	                                "The duration in milliseconds how long it takes to fade off highlighting after inactivating the button",
+	                                0, G_MAXUINT, 1000,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
@@ -470,6 +546,12 @@ static void start_interacting(TangleButton* button) {
 		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->interactive_background_actor);
 	}
 	
+	if (button->priv->highlight_animation) {
+		clutter_animation_completed(button->priv->highlight_animation);
+	}
+	button->priv->highlight_animation = tangle_object_animate(G_OBJECT(button->priv->highlight_effect), CLUTTER_LINEAR, button->priv->highlight_activate_duration, "distance", button->priv->highlight_distance, NULL);
+	g_object_add_weak_pointer(G_OBJECT(button->priv->highlight_animation), (gpointer*)&button->priv->highlight_animation);
+	
 	button->priv->button_release_event_handler_actor = clutter_actor_get_stage(CLUTTER_ACTOR(button));
 	g_object_add_weak_pointer(G_OBJECT(button->priv->button_release_event_handler_actor), (gpointer*)&button->priv->button_release_event_handler_actor);
 	g_signal_connect(button->priv->button_release_event_handler_actor, "button-release-event", G_CALLBACK(on_button_release_event), button);
@@ -485,6 +567,12 @@ static void end_interacting(TangleButton* button) {
 		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
 	}
 
+	if (button->priv->highlight_animation) {
+		clutter_animation_completed(button->priv->highlight_animation);
+	}
+	button->priv->highlight_animation = tangle_object_animate(G_OBJECT(button->priv->highlight_effect), CLUTTER_LINEAR, button->priv->highlight_inactivate_duration, "distance", 0.0, NULL);
+	g_object_add_weak_pointer(G_OBJECT(button->priv->highlight_animation), (gpointer*)&button->priv->highlight_animation);
+
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), FALSE);
 }
 
@@ -559,6 +647,11 @@ static void on_notify_ancestor_interacting(GObject* object, GParamSpec* param_sp
 
 static void tangle_button_init(TangleButton* button) {
 	button->priv = G_TYPE_INSTANCE_GET_PRIVATE(button, TANGLE_TYPE_BUTTON, TangleButtonPrivate);
+
+	button->priv->highlight_distance = 7.0;
+	button->priv->highlight_activate_duration = 250;
+	button->priv->highlight_inactivate_duration = 1000;
+
 	clutter_actor_set_reactive(CLUTTER_ACTOR(button), TRUE);
 	g_signal_connect(button, "button-press-event", G_CALLBACK(on_button_press_event), NULL);
 	g_signal_connect(button, "enter-event", G_CALLBACK(on_enter_event), NULL);
