@@ -68,6 +68,7 @@ GType tangle_layout_direction_get_type(void) {
 }
 
 TangleWidget* tangle_layout_get_widget(TangleLayout* layout) {
+	g_return_val_if_fail(TANGLE_IS_LAYOUT(layout), NULL);
 
 	return layout->priv->widget;
 }
@@ -96,6 +97,8 @@ void tangle_layout_set_widget(TangleLayout* layout, TangleWidget* widget) {
 void tangle_layout_get_preferred_width(TangleLayout* layout, gfloat for_height, gfloat* min_width_p, gfloat* natural_width_p) {
 	TangleLayoutClass* layout_class;
 	GList* trick;
+
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
 	
 	layout_class = TANGLE_LAYOUT_GET_CLASS(layout);
 	if (layout->priv->direction & TANGLE_LAYOUT_DIRECTION_VERTICAL_FIRST) {
@@ -118,6 +121,8 @@ void tangle_layout_get_preferred_width(TangleLayout* layout, gfloat for_height,
 }
 
 void tangle_layout_get_preferred_actor_width(TangleLayout* layout, ClutterActor* actor, gfloat for_height, gfloat* min_width_p, gfloat* natural_width_p) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (layout->priv->direction & TANGLE_LAYOUT_DIRECTION_VERTICAL_FIRST) {
 		clutter_actor_get_preferred_height(actor, for_height, min_width_p, natural_width_p);
 	} else {
@@ -126,6 +131,8 @@ void tangle_layout_get_preferred_actor_width(TangleLayout* layout, ClutterActor*
 }
 
 void tangle_layout_get_preferred_interacting_width(TangleLayout* layout, ClutterActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (TANGLE_IS_ACTOR(actor)) {
 		if (layout->priv->direction & TANGLE_LAYOUT_DIRECTION_VERTICAL_FIRST) {
 			tangle_actor_get_preferred_height(TANGLE_ACTOR(actor), for_height, interacting, min_width_p, natural_width_p, max_width_p);
@@ -148,6 +155,8 @@ void tangle_layout_get_preferred_height(TangleLayout* layout, gfloat for_width,
 	TangleLayoutClass* layout_class;
 	GList* trick;
 	
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	layout_class = TANGLE_LAYOUT_GET_CLASS(layout);
 	if (layout->priv->direction & TANGLE_LAYOUT_DIRECTION_VERTICAL_FIRST) {
 		if (layout_class->get_preferred_width) {
@@ -169,6 +178,8 @@ void tangle_layout_get_preferred_height(TangleLayout* layout, gfloat for_width,
 }
 
 void tangle_layout_get_preferred_actor_height(TangleLayout* layout, ClutterActor* actor, gfloat for_width, gfloat* min_height_p, gfloat* natural_height_p) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (layout->priv->direction & TANGLE_LAYOUT_DIRECTION_VERTICAL_FIRST) {
 		clutter_actor_get_preferred_height(actor, for_width, min_height_p, natural_height_p);
 	} else {
@@ -177,6 +188,8 @@ void tangle_layout_get_preferred_actor_height(TangleLayout* layout, ClutterActor
 }
 
 void tangle_layout_get_preferred_interactive_height(TangleLayout* layout, ClutterActor* actor, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (TANGLE_IS_ACTOR(actor)) {
 		if (layout->priv->direction & TANGLE_LAYOUT_DIRECTION_VERTICAL_FIRST) {
 			tangle_actor_get_preferred_width(TANGLE_ACTOR(actor), for_width, interacting, min_height_p, natural_height_p, max_height_p);
@@ -199,6 +212,8 @@ void tangle_layout_allocate(TangleLayout* layout, const ClutterActorBox* box, Cl
 	GList* trick;
 	TangleLayoutClass* layout_class;
 	
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	layout->priv->allocation = *box;
 
 	for (trick = g_list_last(layout->priv->tricks); trick; trick = g_list_previous(trick)) {
@@ -219,6 +234,8 @@ void tangle_layout_allocate_actor(TangleLayout* layout, ClutterActor* actor, Clu
 	ClutterActorBox translated_box;
 	GList* trick;
 	gfloat x, y;
+
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
 	
 	switch (layout->priv->direction) {
 		case TANGLE_LAYOUT_DIRECTION_LTR_TTB:
@@ -291,11 +308,14 @@ void tangle_layout_allocate_actor(TangleLayout* layout, ClutterActor* actor, Clu
 }
 
 TangleLayoutDirection tangle_layout_get_direction(TangleLayout* layout) {
+	g_return_val_if_fail(TANGLE_IS_LAYOUT(layout), TANGLE_LAYOUT_DIRECTION_LTR_TTB);
 
 	return layout->priv->direction;
 }
 
 void tangle_layout_set_direction(TangleLayout* layout, TangleLayoutDirection direction) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (layout->priv->direction != direction) {
 		layout->priv->direction = direction;
 		g_object_notify(G_OBJECT(layout), "direction");
@@ -304,11 +324,14 @@ void tangle_layout_set_direction(TangleLayout* layout, TangleLayoutDirection dir
 }
 
 gboolean tangle_layout_get_use_fixed_position(TangleLayout* layout) {
+	g_return_val_if_fail(TANGLE_IS_LAYOUT(layout), FALSE);
 
 	return layout->priv->use_fixed_position;
 }
 
 void tangle_layout_set_use_fixed_position(TangleLayout* layout, gboolean use_fixed_position) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (layout->priv->use_fixed_position != use_fixed_position) {
 		layout->priv->use_fixed_position = use_fixed_position;
 		g_object_notify(G_OBJECT(layout), "use-fixed-position");
@@ -317,6 +340,7 @@ void tangle_layout_set_use_fixed_position(TangleLayout* layout, gboolean use_fix
 }
 
 GList* tangle_layout_get_tricks(TangleLayout* layout) {
+	g_return_val_if_fail(TANGLE_IS_LAYOUT(layout), NULL);
 
 	return g_list_copy(layout->priv->tricks);
 }
@@ -326,6 +350,7 @@ TangleTrick* tangle_layout_get_trick_by_type(TangleLayout* layout, GType type) {
 	GList* list;
 	GList* list_item;
 	
+	g_return_val_if_fail(TANGLE_IS_LAYOUT(layout), NULL);
 	g_return_val_if_fail(g_type_is_a(type, TANGLE_TYPE_TRICK), NULL);
 	
 	for (list_item = layout->priv->tricks; list_item; list_item = list_item->next) {
@@ -339,6 +364,8 @@ TangleTrick* tangle_layout_get_trick_by_type(TangleLayout* layout, GType type) {
 }
 
 void tangle_layout_add_trick(TangleLayout* layout, TangleTrick* trick) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (g_list_find(layout->priv->tricks, trick)) {
 		g_warning("Trying to add a same trick into a layout more than once, skipped.");
 	} else {
@@ -355,6 +382,8 @@ void tangle_layout_add_trick(TangleLayout* layout, TangleTrick* trick) {
 void tangle_layout_remove_trick(TangleLayout* layout, TangleTrick* trick) {
 	GList* list_element;
 
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	if (!(list_element = g_list_find(layout->priv->tricks, trick))) {
 		g_warning("Trying to remove a trick that has not added into a layout, skipped.");
 	} else {
@@ -370,6 +399,8 @@ void tangle_layout_remove_trick(TangleLayout* layout, TangleTrick* trick) {
 	
 void tangle_layout_clear_tricks(TangleLayout* layout) {
 	GList* list_element;
+
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
 	
 	if (layout->priv->tricks) {
 		for (list_element = layout->priv->tricks; list_element; list_element = list_element->next) {
@@ -389,6 +420,8 @@ TangleLayoutMeta* tangle_layout_get_meta(TangleLayout* layout, ClutterActor* act
 	TangleLayoutMeta* layout_meta;
 	TangleLayoutClass* layout_class;
 	
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	layout_class = TANGLE_LAYOUT_GET_CLASS(layout);
 	
 	if (!(layout_meta = g_object_get_qdata(G_OBJECT(actor), quark_layout_meta)) ||
@@ -405,6 +438,8 @@ TangleLayoutMeta* tangle_layout_get_meta(TangleLayout* layout, ClutterActor* act
 }
 
 void tangle_layout_changed(TangleLayout* layout) {
+	g_return_if_fail(TANGLE_IS_LAYOUT(layout));
+
 	g_signal_emit(layout, signals[CHANGED], 0);
 }
 
