@@ -447,28 +447,30 @@ gchar* tangle_lookup_filename(const gchar* filename) {
 	gchar** csp;
 	gchar* dir;
 	
-	if (g_path_is_absolute(filename)) {
-		path = g_strdup(filename);
-	} else {
-		if (search_paths) {
-			for (csp = search_paths; !path && *csp; csp++) {
-				path = g_build_filename(*csp, filename, NULL);
+	if (filename) {
+		if (g_path_is_absolute(filename)) {
+			path = g_strdup(filename);
+		} else {
+			if (search_paths) {
+				for (csp = search_paths; !path && *csp; csp++) {
+					path = g_build_filename(*csp, filename, NULL);
+					if (!g_file_test(path, G_FILE_TEST_EXISTS)) {
+						g_free(path);
+						path = NULL;
+					}
+				}
+			}
+
+			if (!path) {
+				dir = g_get_current_dir();
+				path = g_build_filename(dir, filename, NULL);
 				if (!g_file_test(path, G_FILE_TEST_EXISTS)) {
 					g_free(path);
 					path = NULL;
 				}
+				g_free(dir);
 			}
 		}
-		
-		if (!path) {
-			dir = g_get_current_dir();
-			path = g_build_filename(dir, filename, NULL);
-			if (!g_file_test(path, G_FILE_TEST_EXISTS)) {
-				g_free(path);
-				path = NULL;
-			}
-			g_free(dir);
-		}
 	}
 	
 	return path;
@@ -487,6 +489,8 @@ ClutterAnimation* tangle_object_animate(GObject* object, gulong mode, guint dura
 	ClutterAnimation* animation;
 	va_list args;
 	
+	g_return_val_if_fail(G_IS_OBJECT(object), NULL);
+
 	animation = clutter_animation_new();
 	clutter_animation_set_mode(animation, mode);
 	clutter_animation_set_duration(animation, duration);
@@ -502,6 +506,8 @@ ClutterAnimation* tangle_object_animate_with_timeline(GObject* object, gulong mo
 	ClutterAnimation* animation;
 	va_list args;
 	
+	g_return_val_if_fail(G_IS_OBJECT(object), NULL);
+
 	animation = clutter_animation_new();
 	clutter_animation_set_mode(animation, mode);
 	clutter_animation_set_timeline(animation, timeline);
@@ -516,6 +522,8 @@ ClutterAnimation* tangle_object_animate_with_timeline(GObject* object, gulong mo
 ClutterAnimation* tangle_object_animatev(GObject* object, gulong mode, guint duration, gint n_properties, const gchar* const property_names[], const GValue* property_values) {
 	ClutterAnimation* animation;
 	
+	g_return_val_if_fail(G_IS_OBJECT(object), NULL);
+
 	animation = clutter_animation_new();
 	clutter_animation_set_mode(animation, mode);
 	clutter_animation_set_duration(animation, duration);
@@ -528,6 +536,8 @@ ClutterAnimation* tangle_object_animatev(GObject* object, gulong mode, guint dur
 ClutterAnimation* tangle_object_animate_valist(GObject* object, gulong mode, guint duration, va_list properties) {
 	ClutterAnimation* animation;
 	
+	g_return_val_if_fail(G_IS_OBJECT(object), NULL);
+
 	animation = clutter_animation_new();
 	clutter_animation_set_mode(animation, mode);
 	clutter_animation_set_duration(animation, duration);
@@ -540,6 +550,8 @@ ClutterAnimation* tangle_object_animate_valist(GObject* object, gulong mode, gui
 ClutterAnimation* tangle_object_animate_valist_with_timeline(GObject* object, gulong mode, ClutterTimeline* timeline, va_list properties) {
 	ClutterAnimation* animation;
 	va_list args;
+
+	g_return_val_if_fail(G_IS_OBJECT(object), NULL);
 	
 	animation = clutter_animation_new();
 	clutter_animation_set_mode(animation, mode);
@@ -558,6 +570,8 @@ static gboolean is_value_user_data(gpointer key, gpointer value, gpointer user_d
 gboolean tangle_object_stop_animation(GObject* object, ClutterAnimation* animation) {
 	gboolean retvalue = FALSE;
 	GHashTable* animations;
+
+	g_return_val_if_fail(G_IS_OBJECT(object), FALSE);
 	
 	animations = get_animations_hash_table(object);
 	
