@@ -88,6 +88,8 @@ ClutterAction* tangle_scroll_action_new() {
 }
 
 void tangle_scroll_action_get_offsets(TangleScrollAction* scroll_action, gfloat* offset_x_return, gfloat* offset_y_return) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (offset_x_return) {
 		*offset_x_return = scroll_action->priv->offset[HORIZONTAL];
 	}
@@ -97,6 +99,8 @@ void tangle_scroll_action_get_offsets(TangleScrollAction* scroll_action, gfloat*
 }
 
 void tangle_scroll_action_set_offsets(TangleScrollAction* scroll_action, gfloat offset_x, gfloat offset_y) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (scroll_action->priv->offset[HORIZONTAL] != offset_x) {
 		scroll_action->priv->offset[HORIZONTAL] = normalise_offset(scroll_action, HORIZONTAL, offset_x, NULL);
 		g_object_notify(G_OBJECT(scroll_action), "offset-x");
@@ -108,6 +112,8 @@ void tangle_scroll_action_set_offsets(TangleScrollAction* scroll_action, gfloat
 }
 
 void tangle_scroll_action_get_max_offsets(TangleScrollAction* scroll_action, gfloat* max_offset_x_return, gfloat* max_offset_y_return) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (max_offset_x_return) {
 		*max_offset_x_return = scroll_action->priv->max_offset[HORIZONTAL];
 	}
@@ -119,6 +125,8 @@ void tangle_scroll_action_get_max_offsets(TangleScrollAction* scroll_action, gfl
 void tangle_scroll_action_set_max_offsets(TangleScrollAction* scroll_action, gfloat max_offset_x, gfloat max_offset_y) {
 	gboolean changed = FALSE;
 	
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (scroll_action->priv->max_offset[HORIZONTAL] != max_offset_x) {
 		scroll_action->priv->max_offset[HORIZONTAL] =max_offset_x;
 		g_object_notify(G_OBJECT(scroll_action), "max-offset-x");
@@ -132,6 +140,8 @@ void tangle_scroll_action_set_max_offsets(TangleScrollAction* scroll_action, gfl
 }
 
 void tangle_scroll_action_get_thresholds(TangleScrollAction* scroll_action, gfloat* threshold_x_return, gfloat* threshold_y_return) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (threshold_x_return) {
 		*threshold_x_return = scroll_action->priv->threshold[HORIZONTAL];
 	}
@@ -141,6 +151,8 @@ void tangle_scroll_action_get_thresholds(TangleScrollAction* scroll_action, gflo
 }
 
 void tangle_scroll_action_set_thresholds(TangleScrollAction* scroll_action, gfloat threshold_x, gfloat threshold_y) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (scroll_action->priv->threshold[HORIZONTAL] != threshold_x) {
 		scroll_action->priv->threshold[HORIZONTAL] =threshold_x;
 		g_object_notify(G_OBJECT(scroll_action), "threshold-x");
@@ -153,6 +165,8 @@ void tangle_scroll_action_set_thresholds(TangleScrollAction* scroll_action, gflo
 
 
 void tangle_scroll_action_get_max_overshoots(TangleScrollAction* scroll_action, gfloat* max_overshoot_x_return, gfloat* max_overshoot_y_return) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (max_overshoot_x_return) {
 		*max_overshoot_x_return = scroll_action->priv->max_overshoot[HORIZONTAL];
 	}
@@ -162,6 +176,8 @@ void tangle_scroll_action_get_max_overshoots(TangleScrollAction* scroll_action,
 }
 
 void tangle_scroll_action_set_max_overshoots(TangleScrollAction* scroll_action, gfloat max_overshoot_x, gfloat max_overshoot_y) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	gboolean changed = FALSE;
 	
 	if (scroll_action->priv->max_overshoot[HORIZONTAL] != max_overshoot_x) {
@@ -178,6 +194,8 @@ void tangle_scroll_action_set_max_overshoots(TangleScrollAction* scroll_action,
 
 
 void tangle_scroll_action_get_continuous(TangleScrollAction* scroll_action, gboolean* continuous_x_return, gboolean* continuous_y_return) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (continuous_x_return) {
 		*continuous_x_return = scroll_action->priv->continuous[HORIZONTAL];
 	}
@@ -187,6 +205,8 @@ void tangle_scroll_action_get_continuous(TangleScrollAction* scroll_action, gboo
 }
 
 void tangle_scroll_action_set_continuous(TangleScrollAction* scroll_action, gboolean continuous_x, gboolean continuous_y) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	gboolean changed = FALSE;
 	
 	if (scroll_action->priv->continuous[HORIZONTAL] != continuous_x) {
@@ -202,11 +222,14 @@ void tangle_scroll_action_set_continuous(TangleScrollAction* scroll_action, gboo
 }
 
 gboolean tangle_scroll_action_get_kinetic_scrolling(TangleScrollAction* scroll_action) {
+	g_return_val_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action), FALSE);
 
 	return scroll_action->priv->kinetic_scrolling;
 }
 
 void tangle_scroll_action_set_kinetic_scrolling(TangleScrollAction* scroll_action, gboolean kinetic_scrolling) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (scroll_action->priv->kinetic_scrolling != kinetic_scrolling) {
 		scroll_action->priv->kinetic_scrolling = kinetic_scrolling;
 		g_object_notify(G_OBJECT(scroll_action), "kinetic-scrolling");
@@ -214,11 +237,15 @@ void tangle_scroll_action_set_kinetic_scrolling(TangleScrollAction* scroll_actio
 }
 
 gdouble tangle_scroll_action_get_deceleration(TangleScrollAction* scroll_action) {
+	g_return_val_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action), 0.0);
+
 
 	return scroll_action->priv->deceleration;
 }
 
 void tangle_scroll_action_set_deceleration(TangleScrollAction* scroll_action, gdouble deceleration) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (scroll_action->priv->deceleration != deceleration) {
 		scroll_action->priv->deceleration = deceleration;
 		g_object_notify(G_OBJECT(scroll_action), "deceleration");
@@ -226,11 +253,14 @@ void tangle_scroll_action_set_deceleration(TangleScrollAction* scroll_action, gd
 }
 
 gboolean tangle_scroll_action_get_bind_to_scroll_trick(TangleScrollAction* scroll_action) {
+	g_return_val_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action), FALSE);
 
 	return scroll_action->priv->bind_to_scroll_trick;
 }
 
 void tangle_scroll_action_set_bind_to_scroll_trick(TangleScrollAction* scroll_action, gboolean bind_to_scroll_trick) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	if (scroll_action->priv->bind_to_scroll_trick != bind_to_scroll_trick) {
 		scroll_action->priv->bind_to_scroll_trick = bind_to_scroll_trick;
 		g_object_notify(G_OBJECT(scroll_action), "bind-to-scroll-trick");
@@ -240,6 +270,8 @@ void tangle_scroll_action_set_bind_to_scroll_trick(TangleScrollAction* scroll_ac
 void tangle_scroll_action_clamp_offset_x(TangleScrollAction* scroll_action) {
 	TangleClamp* clamp;
 	
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	clamp = tangle_clamp_new(TANGLE_CLAMP_HORIZONTAL, scroll_action->priv->offset[HORIZONTAL]);
 	g_signal_emit(scroll_action, signals[CLAMP_OFFSET_X], 0, clamp);
 	if (tangle_clamp_get_clamped_value_set(clamp)) {
@@ -251,6 +283,8 @@ void tangle_scroll_action_clamp_offset_x(TangleScrollAction* scroll_action) {
 void tangle_scroll_action_clamp_offset_y(TangleScrollAction* scroll_action) {
 	TangleClamp* clamp;
 	
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	clamp = tangle_clamp_new(TANGLE_CLAMP_VERTICAL, scroll_action->priv->offset[VERTICAL]);
 	g_signal_emit(scroll_action, signals[CLAMP_OFFSET_Y], 0, clamp);
 	if (tangle_clamp_get_clamped_value_set(clamp)) {
@@ -260,11 +294,15 @@ void tangle_scroll_action_clamp_offset_y(TangleScrollAction* scroll_action) {
 }
 
 void tangle_scroll_action_clamp_offsets(TangleScrollAction* scroll_action) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	tangle_scroll_action_clamp_offset_x(scroll_action);
 	tangle_scroll_action_clamp_offset_y(scroll_action);
 }
 
 void tangle_scroll_action_bind_to_scroll_trick(TangleScrollAction* scroll_action, TangleScrollTrick* scroll_trick) {
+	g_return_if_fail(TANGLE_IS_SCROLL_ACTION(scroll_action));
+
 	tangle_binding_new(G_OBJECT(scroll_action), "offset-x", G_OBJECT(scroll_trick), "offset-x");
 	tangle_binding_new(G_OBJECT(scroll_action), "offset-y", G_OBJECT(scroll_trick), "offset-y");
 	tangle_binding_new(G_OBJECT(scroll_action), "max-offset-x", G_OBJECT(scroll_trick), "max-offset-x");
