@@ -11,8 +11,6 @@
 #define __TANGLE_SCROLLBAR_H__
 
 #include "tangle-widget.h"
-#include "tangle-scrolling-actor.h"
-#include "tangle-scroller.h"
 
 #define TANGLE_TYPE_SCROLLBAR (tangle_scrollbar_get_type())
 #define TANGLE_SCROLLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), TANGLE_TYPE_SCROLLBAR, TangleScrollbar))
@@ -41,7 +39,4 @@ gboolean tangle_scrollbar_get_vertical(TangleScrollbar* scrollbar);
 ClutterActor* tangle_scrollbar_get_bar_actor(TangleScrollbar* scrollbar);
 void tangle_scrollbar_set_bar_actor(TangleScrollbar* scrollbar, ClutterActor* bar_actor);
 
-void tangle_scrollbar_bind_to_scrolling_actor(TangleScrollbar* scrollbar, TangleScrollingActor* scrolling_actor);
-void tangle_scrollbar_bind_to_scroller(TangleScrollbar* scrollbar, TangleScroller* scroller);
-
 #endif
