@@ -65,6 +65,7 @@ TangleTemplate* tangle_template_new(GType object_type) {
 }
 
 GType tangle_template_get_object_type(TangleTemplate* template) {
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), G_TYPE_NONE);
 
 	return template->priv->object_type;
 }
@@ -74,6 +75,8 @@ GObject* tangle_template_create_object(TangleTemplate* template) {
 	const gchar* template_id;
 	gchar* id = NULL;
 
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), NULL);
+
 	if ((template_id = clutter_get_script_id(G_OBJECT(template)))) {
 		id = g_strdup_printf("%s$$%d", template_id, template->priv->instance_counter);
 	}
@@ -98,6 +101,8 @@ GObject* tangle_template_create_object_with_id(TangleTemplate* template, const g
 	ClutterScriptableIface* scriptable_iface;
 	GParameter* parameter;
 
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), NULL);
+
 	parameters = tangle_properties_get_as_parameters(TANGLE_PROPERTIES(template), &n);
 	construct_parameters = g_array_new(FALSE, FALSE, sizeof(GParameter));
 	nonconstruct_parameters = g_array_new(FALSE, FALSE, sizeof(GParameter));
@@ -178,6 +183,8 @@ GObject* tangle_template_create_object_with_id(TangleTemplate* template, const g
 
 void tangle_template_apply_properties(TangleTemplate* template, GObject* object) {
 	TangleVault* vault;
+
+	g_return_if_fail(TANGLE_IS_TEMPLATE(template));
 	
 	vault = tangle_vault_new(4, TANGLE_TYPE_TEMPLATE, template, G_TYPE_OBJECT, object, G_TYPE_ULONG, (gulong)0, G_TYPE_UINT, (guint)0);
 	tangle_properties_foreach(TANGLE_PROPERTIES(template), set_property, vault);
@@ -189,12 +196,17 @@ void tangle_template_apply_properties(TangleTemplate* template, GObject* object)
 void tangle_template_animate_properties(TangleTemplate* template, ClutterActor* actor, gulong mode, guint duration) {
 	TangleVault* vault;
 	
+	g_return_if_fail(TANGLE_IS_TEMPLATE(template));
+
 	vault = tangle_vault_new(4, TANGLE_TYPE_TEMPLATE, template, G_TYPE_OBJECT, G_OBJECT(actor), G_TYPE_ULONG, mode, G_TYPE_UINT, duration);
 	tangle_properties_foreach(TANGLE_PROPERTIES(template), set_property, vault);
 	tangle_vault_free(vault);
 }
-ngle_template_apply_properties_on_signal(TangleTemplate* template, GObject* target_object, GObject* signal_object, const gchar* signal_name, gboolean signal_return) {
+
+gulong tangle_template_apply_properties_on_signal(TangleTemplate* template, GObject* target_object, GObject* signal_object, const gchar* signal_name, gboolean signal_return) {
 	TangleVault* vault;
+
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), 0);
 	
 	vault = tangle_vault_new(5, TANGLE_TYPE_TEMPLATE, template, G_TYPE_OBJECT, target_object, G_TYPE_ULONG, (gulong)0, G_TYPE_UINT, (guint)0, G_TYPE_BOOLEAN, signal_return);
 	
@@ -204,27 +216,33 @@ ngle_template_apply_properties_on_signal(TangleTemplate* template, GObject* targ
 gulong tangle_template_animate_properties_on_signal(TangleTemplate* template, ClutterActor* actor, gulong mode, guint duration, GObject* signal_object, const gchar* signal_name, gboolean signal_return) {
 	TangleVault* vault;
 	
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), 0);
+
 	vault = tangle_vault_new(5, TANGLE_TYPE_TEMPLATE, template, G_TYPE_OBJECT, G_OBJECT(actor), G_TYPE_ULONG, mode, G_TYPE_UINT, duration, G_TYPE_BOOLEAN, signal_return);
 	
 	return tangle_signal_connect_vault_flags(signal_object, signal_name, G_CALLBACK(on_signal), vault, G_CONNECT_SWAPPED);
 }
 
 gboolean tangle_template_has_parameters(TangleTemplate* template) {
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), FALSE);
 
 	return g_hash_table_size(template->priv->parameters) > 0;
 }
 
 GList* tangle_template_get_parameter_names(TangleTemplate* template) {
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), NULL);
 
 	return g_hash_table_get_keys(template->priv->parameters);
 }
 
 gboolean tangle_template_has_parameter(TangleTemplate* template, const gchar* name) {
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), FALSE);
 
 	return g_hash_table_lookup_extended(template->priv->parameters, name, NULL, NULL);
 }
 
 const GValue* tangle_template_get_parameter_value(TangleTemplate* template, const gchar* name) {
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), NULL);
 	
 	return g_hash_table_lookup(template->priv->parameters, name);
 }
@@ -233,6 +251,8 @@ gboolean tangle_template_set_parameter_value(TangleTemplate* template, const gch
 	gboolean retvalue = FALSE;
 	GValue* value_copy;
 
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), FALSE);
+
 	if (g_hash_table_lookup_extended(template->priv->parameters, name, NULL, NULL)) {
 		value_copy = g_value_init(g_new0(GValue, 1), G_VALUE_TYPE(value));
 		g_value_copy(value, value_copy);
@@ -248,6 +268,8 @@ void tangle_template_clear_parameter_values(TangleTemplate* template) {
 	GList* list;
 	GList* list_item;
 
+	g_return_if_fail(TANGLE_IS_TEMPLATE(template));
+
 	list = g_hash_table_get_keys(template->priv->parameters);
 	for (list_item = list; list_item; list_item = list_item->next) {
 		g_hash_table_insert(template->priv->parameters, g_strdup(list_item->data), NULL);
@@ -258,6 +280,8 @@ void tangle_template_clear_parameter_values(TangleTemplate* template) {
 gboolean tangle_template_are_parameters_complete(TangleTemplate* template) {
 	gboolean found = FALSE;
 
+	g_return_val_if_fail(TANGLE_IS_TEMPLATE(template), FALSE);
+
 	g_hash_table_find(template->priv->parameters, is_value_null, &found);
 
 	return !found;
