@@ -56,6 +56,8 @@ ClutterActor* tangle_view_new_with_layout(TangleLayout* layout) {
 void tangle_view_set_filename(TangleView* view, const gchar* filename) {
 	GError* error = NULL;
 
+	g_return_if_fail(TANGLE_IS_VIEW(view));
+
 	if (g_strcmp0(view->priv->filename, filename)) {
 		tangle_view_unload(view);
 		g_free(view->priv->filename);
@@ -68,6 +70,7 @@ void tangle_view_set_filename(TangleView* view, const gchar* filename) {
 }
 
 const gchar* tangle_view_get_filename(TangleView* view) {
+	g_return_val_if_fail(TANGLE_IS_VIEW(view), NULL);
 
 	return view->priv->filename;
 }
@@ -75,6 +78,7 @@ const gchar* tangle_view_get_filename(TangleView* view) {
 void tangle_view_load_now(TangleView* view) {
 	GError* error = NULL;
 
+	g_return_if_fail(TANGLE_IS_VIEW(view));
 	g_return_if_fail(view->priv->filename != NULL);
 
 	if (!view->priv->loaded) {
@@ -246,7 +250,7 @@ static void add_orphans_to_container(TangleView* view) {
 	for (list = objects; list; list = list->next) {
 		if (list->data != (gpointer)view && CLUTTER_IS_ACTOR(list->data) && !TANGLE_IS_VIEW(list->data)) {
 			actor = CLUTTER_ACTOR(list->data);
-			if (!clutter_actor_get_parent(actor) && !tangle_actor_get_warehouse_parent(actor)) {
+			if (!clutter_actor_get_parent(actor)) {
 				clutter_container_add_actor(CLUTTER_CONTAINER(view), actor);
 			}
 		}
