@@ -119,21 +119,25 @@ ClutterActor* tangle_widget_new_scrollable(TangleLayout* layout) {
 
 
 guint tangle_widget_get_n_children(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), 0);
 
 	return g_list_length(widget->priv->children);
 }
 
 ClutterActor* tangle_widget_get_nth_child(TangleWidget* widget, guint n) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), NULL);
 
 	return CLUTTER_ACTOR(g_list_nth_data(widget->priv->children, n));
 }
 
 gboolean tangle_widget_has_child(TangleWidget* widget, ClutterActor* actor) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), FALSE);
 
 	return g_list_find(widget->priv->children, actor) != NULL;
 }
 
 GList* tangle_widget_get_children_readonly(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), NULL);
 
 	return widget->priv->children;
 }
@@ -175,6 +179,8 @@ void tangle_widget_foreach_type_swapped(TangleWidget* widget, GType type, Tangle
 void tangle_widget_add(TangleWidget* widget, ClutterActor* actor, ...) {
 	GList* existing_in_children;
 	
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	existing_in_children = g_list_find_custom(widget->priv->children, actor, compare_actor_if_higher_depth_position);
 	if (existing_in_children) {
 		tangle_widget_add_impl(TANGLE_WIDGET(widget), actor, CLUTTER_ACTOR(existing_in_children->data), TRUE);
@@ -198,6 +204,8 @@ void tangle_widget_add_after(TangleWidget* widget, ClutterActor* actor, ClutterA
 }
 
 void tangle_widget_set_layout(TangleWidget* widget, TangleLayout* layout) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (widget->priv->layout != layout) {
 		if (widget->priv->layout) {
 			g_object_unref(widget->priv->layout);
@@ -217,15 +225,20 @@ void tangle_widget_set_layout(TangleWidget* widget, TangleLayout* layout) {
 }
 
 TangleLayout* tangle_widget_get_layout(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), NULL);
 
 	return widget->priv->layout;
 }
 
 void tangle_widget_get_padding(TangleWidget* widget, TangleSpacing* spacing) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	*spacing = widget->priv->padding;
 }
 	
 void tangle_widget_set_padding(TangleWidget* widget, const TangleSpacing* spacing) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (!widget->priv->padding_set || !tangle_spacing_equal(&widget->priv->padding, spacing)) {
 		g_object_freeze_notify(G_OBJECT(widget));
 		
@@ -251,11 +264,14 @@ void tangle_widget_set_padding(TangleWidget* widget, const TangleSpacing* spacin
 }
 
 gboolean tangle_widget_get_padding_set(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), FALSE);
 
 	return widget->priv->padding_set;
 }
 
 void tangle_widget_set_padding_set(TangleWidget* widget, gboolean is_set) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (widget->priv->padding_set != is_set) {
 		g_object_freeze_notify(G_OBJECT(widget));
 
@@ -269,17 +285,21 @@ void tangle_widget_set_padding_set(TangleWidget* widget, gboolean is_set) {
 }
 
 void tangle_widget_get_background_color(TangleWidget* widget, ClutterColor* color) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
 	g_return_if_fail(color != NULL);
 
 	*color = widget->priv->background_color;
 }
 
 gboolean tangle_widget_get_background_color_set(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), FALSE);
 
 	return widget->priv->background_color_set;
 }
 
 void tangle_widget_set_background_color(TangleWidget* widget, const ClutterColor* color) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (!clutter_color_equal(&widget->priv->background_color, color)) {
 		if (color) {
 			widget->priv->background_color = *color;
@@ -294,6 +314,7 @@ void tangle_widget_set_background_color(TangleWidget* widget, const ClutterColor
 }
 
 ClutterActor* tangle_widget_get_background_actor(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), NULL);
 
 	return widget->priv->background_actor;
 }
@@ -301,6 +322,8 @@ ClutterActor* tangle_widget_get_background_actor(TangleWidget* widget) {
 void tangle_widget_set_background_actor(TangleWidget* widget, ClutterActor* actor) {	
 	ClutterActorBox actor_box;
 
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (widget->priv->background_actor != actor) {
 		if (widget->priv->background_actor && widget->priv->background_parented) {
 			clutter_actor_unparent(widget->priv->background_actor);
@@ -334,6 +357,8 @@ void tangle_widget_set_background_actor(TangleWidget* widget, ClutterActor* acto
 void tangle_widget_change_background_actor(TangleWidget* widget, ClutterActor* actor) {
 	ClutterActorBox actor_box;
 
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (widget->priv->background_actor != actor) {
 		if (widget->priv->background_actor && widget->priv->background_parented) {
 			clutter_actor_unparent(widget->priv->background_actor);
@@ -352,6 +377,7 @@ void tangle_widget_change_background_actor(TangleWidget* widget, ClutterActor* a
 }
 
 ClutterActor* tangle_widget_get_foreground_actor(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), NULL);
 
 	return widget->priv->foreground_actor;
 }
@@ -359,6 +385,8 @@ ClutterActor* tangle_widget_get_foreground_actor(TangleWidget* widget) {
 void tangle_widget_set_foreground_actor(TangleWidget* widget, ClutterActor* actor) {
 	ClutterActorBox actor_box;
 
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (widget->priv->foreground_actor != actor) {
 		if (widget->priv->foreground_actor && widget->priv->foreground_parented) {
 			clutter_actor_unparent(widget->priv->foreground_actor);
@@ -381,11 +409,14 @@ void tangle_widget_set_foreground_actor(TangleWidget* widget, ClutterActor* acto
 }
 
 gboolean tangle_widget_get_prefer_background_size(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), FALSE);
 
 	return widget->priv->prefer_background_size;
 }
 
 void tangle_widget_set_prefer_background_size(TangleWidget* widget, gboolean prefer_background_size) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (!widget->priv->prefer_background_size_set ||
 	    widget->priv->prefer_background_size != prefer_background_size) {
 		widget->priv->prefer_background_size = prefer_background_size;
@@ -396,11 +427,14 @@ void tangle_widget_set_prefer_background_size(TangleWidget* widget, gboolean pre
 }
 
 gboolean tangle_widget_get_prefer_background_size_set(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), FALSE);
 
 	return widget->priv->prefer_background_size_set;
 }
 
 void tangle_widget_set_prefer_background_size_set(TangleWidget* widget, gboolean is_set) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	if (widget->priv->prefer_background_size_set != is_set) {
 		widget->priv->prefer_background_size_set = is_set;
 		clutter_actor_queue_relayout(CLUTTER_ACTOR(widget));
@@ -412,6 +446,8 @@ void tangle_widget_get_real_preferred_size(TangleWidget* widget, gboolean intera
 	ClutterRequestMode request_mode;
 	gfloat natural_size;
 	
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	g_object_get(widget, "request-mode", &request_mode, NULL);
 	if (request_mode == CLUTTER_REQUEST_HEIGHT_FOR_WIDTH) {
 		tangle_widget_get_real_preferred_width(widget, -1, interacting, min_width_p, &natural_size, max_width_p);
@@ -429,19 +465,25 @@ void tangle_widget_get_real_preferred_size(TangleWidget* widget, gboolean intera
 }
 
 void tangle_widget_get_real_preferred_width(TangleWidget* widget, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	tangle_widget_get_preferred_width(TANGLE_ACTOR(widget), for_height, interacting, min_width_p, natural_width_p, max_width_p);
 }
 
 void tangle_widget_get_real_preferred_height(TangleWidget* widget, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
 	tangle_widget_get_preferred_height(TANGLE_ACTOR(widget), for_width, interacting, min_height_p, natural_height_p, max_height_p);
 }
 
 gboolean tangle_widget_get_descendant_interacting(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), FALSE);
 
 	return widget->priv->interacting_descendant != NULL;
 }
 
 gboolean tangle_widget_get_descendant_dragging(TangleWidget* widget) {
+	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), FALSE);
 
 	return widget->priv->dragging_descendant != NULL;
 }
