@@ -11,25 +11,21 @@
 #ifndef __TANGLE_H__
 #define __TANGLE_H__
 
-#include "tangle-action.h"
+#include "tangle-activity.h"
 #include "tangle-actor.h"
-#include "tangle-apply-template-action.h"
 #include "tangle-binding.h"
 #include "tangle-box-layout.h"
 #include "tangle-button.h"
 #include "tangle-button-group.h"
-#include "tangle-call-function-action.h"
 #include "tangle-clamp.h"
 #include "tangle-compound-style.h"
 #include "tangle-curved-transition.h"
 #include "tangle-drag-action.h"
-#include "tangle-draggable-actor.h"
 #include "tangle-drop-action.h"
-#include "tangle-droppable-actor.h"
 #include "tangle-easing-transition.h"
 #include "tangle-fixed-layout.h"
-#include "tangle-floating-actor.h"
 #include "tangle-grid.h"
+#include "tangle-highlight-effect.h"
 #include "tangle-hold-action.h"
 #include "tangle-layout.h"
 #include "tangle-layout-meta.h"
@@ -42,10 +38,6 @@
 #include "tangle-scroll-action.h"
 #include "tangle-scroll-trick.h"
 #include "tangle-scrollbar.h"
-#include "tangle-scroller.h"
-#include "tangle-scrolling-actor.h"
-#include "tangle-set-property-action.h"
-#include "tangle-show-actor-action.h"
 #include "tangle-stack-layout.h"
 #include "tangle-stretch-action.h"
 #include "tangle-stylable.h"
@@ -53,12 +45,11 @@
 #include "tangle-stylesheet.h"
 #include "tangle-timeline.h"
 #include "tangle-template.h"
+#include "tangle-texture.h"
 #include "tangle-transition.h"
 #include "tangle-trick.h"
 #include "tangle-vault.h"
 #include "tangle-view.h"
-#include "tangle-warehouse.h"
 #include "tangle-widget.h"
-#include "tangle-wrapper-actor.h"
 
 #endif
