@@ -26,14 +26,19 @@ int main(int argc, char** argv) {
 	/* Texture2 is actually TangleWrapperActor, because we need
 	 * tangle_actor_set_depth_position() function.
 	 */
+
+/* TODO: The TangleWrapperActor does not exist any more.
+
 	texture2 = tangle_wrapper_actor_new(clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL));
 	clutter_actor_set_position(texture2, 33.0, 33.0);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(texture2), -100);
 
+*/
+
 	texture3 = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
 	clutter_actor_set_position(texture3, 66.0, 66.0);
 
-	clutter_container_add(CLUTTER_CONTAINER(widget), texture1, texture2, texture3, NULL);
+	clutter_container_add(CLUTTER_CONTAINER(widget), texture1, /* TODO: texture2, */ texture3, NULL);
 	
 	clutter_actor_show_all(stage);	
 	clutter_main();
