@@ -14,7 +14,7 @@ int main(int argc, char** argv) {
 	
 	tangle_value_divide(&a, &b);
 	
-	g_print("%f\n", g_value_get_float(&a));
+	g_print("%d %f %d\n", tangle_value_is_calculation_supported(G_TYPE_FLOAT), g_value_get_float(&a), tangle_value_compare(&a, &b));
 	
 	return 0;
 }
